@@ -134,7 +134,8 @@ class DataPlate:
               es_index_type=None,
               bucket_suffixes=None,
               bucket_filter=None,
-              force_scheme_change=False):
+              force_scheme_change=False,
+              recursive_lookup_no_partitions=False):
         """
         Executes remote SQL query, and saves results to the specified file.
 
@@ -161,6 +162,11 @@ class DataPlate:
             In case scheme was change in the data meant to read/query use this to indicate spark to re-create the temporary view
             Use this only if case you want to read parquet files that were written with dataset=True and mode="overwrite_partitions"
             and where the overwrite scheme was changed
+        recursive_lookup_no_partitions: boolean
+            We recommend defining sub-folders as partitions instead of using this
+            Note: this requires an EMR cluster > 6.3.0 with spark 3
+            If True you'll be able to read data from subfolders, even though no partitions were defined
+            default is False - meaning you have to define sub-folders as partitions (e.g "customer=customer1")
         """
         headers = {'X-Access-Key': self.access_key}
         params = {}
@@ -177,6 +183,8 @@ class DataPlate:
             params['bucket_filter'] = bucket_filter
         if force_scheme_change:
             params['force_scheme_change'] = force_scheme_change
+        if recursive_lookup_no_partitions:
+            params['recursive_lookup_no_partitions'] = recursive_lookup_no_partitions
 
         retries = 1
         while True:
@@ -224,6 +232,7 @@ class DataPlate:
                     bucket_suffixes=None,
                     bucket_filter=None,
                     force_scheme_change=False,
+                    recursive_lookup_no_partitions=False,
                     **kwargs):
         """
         Executes remote SQL query, and returns Pandas dataframe.
@@ -250,6 +259,11 @@ class DataPlate:
             In case scheme was change in the data meant to read/query use this to indicate spark to re-create the temporary view
             Use this only if case you want to read parquet files that were written with dataset=True and mode="overwrite_partitions"
             and where the overwrite scheme was changed
+        recursive_lookup_no_partitions: boolean
+            We recommend defining sub-folders as partitions instead of using this
+            Note: this requires an EMR cluster > 6.3.0 with spark 3
+            If True you'll be able to read data from subfolders, even though no partitions were defined
+            default is False - meaning you have to define sub-folders as partitions (e.g "customer=customer1")
         **kwargs : params
             Arbitrary parameters to pass to `pandas.read_json()` method
 
@@ -260,7 +274,7 @@ class DataPlate:
         import pandas as pd
         with tempfile.NamedTemporaryFile(suffix='.gz') as t:
             output_file = t.name
-            self.query(query, output_file, refresh, async_m, request_timeout, es_index_type, bucket_suffixes, bucket_filter, force_scheme_change)
+            self.query(query, output_file, refresh, async_m, request_timeout, es_index_type, bucket_suffixes, bucket_filter, force_scheme_change, recursive_lookup_no_partitions)
             with open(output_file, 'rb') as fh:
                 return pd.read_json(fh, compression='gzip', lines=True, **kwargs)
 
